<?php
/**
 *    @version 2.1.1 Build 21106 Alpha [ Drury ]
 *    @package hwdVideoShare
 *    @copyright (C) 2007 - 2009 Highwood Design
 *    @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 ***
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
defined( '_JEXEC' ) or die( 'Direct Access to this location is not allowed.' );

/**
 * @package    hwdVideoShare
 * @author     Dave Horsfall <info@highwooddesign.co.uk>
 * @copyright  2008 Highwood Design
 * @license    http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @version    1.1.4 Alpha RC3.5
 */
class hwd_vs_tp {
    /**
     * Extracts the appropriate third party video code used to generate
     * the player and thumbnail images
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_code   the third party video code
     */
	function processcode($option)
	{
		$code = hwd_vs_tp::getcode($option);
		if (!empty($code)) {
			$thumbnail = hwd_vs_tp::getthumbnail($code[0]);
			$ext_v_code[0] = true;
			$ext_v_code[1] = $code[0].",".$thumbnail.",".$code[1];

		} else {
			$ext_v_code[0] = false;
			$ext_v_code[1] = "";
		}
		return $ext_v_code;
	}
    /**
     * Extracts the appropriate third party video code used to generate
     * the player and thumbnail images
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_code   the third party video code
     */
	function getcode($option)
	{
		// check for embed code format
		$pos_e = strpos($option, "youtube.com/v/");
		$pos_u = strpos($option, "watch?v=");

		if ($pos_e === false && $pos_u === false) {
			return null;
		} else if ($pos_e) {
			$pos_e_start = $pos_e + 14;

			$code = substr($option, $pos_e_start, 11);
			$code = strip_tags($code );
			$code = preg_replace("/[^a-zA-Z0-9s_-]/", "", $code);
		} else if ($pos_u) {
			$pos_u_start = $pos_u + 8;

			$code = substr($option, $pos_u_start, 11);
			$code = strip_tags($code );
			$code = preg_replace("/[^a-zA-Z0-9s_-]/", "", $code);
		}

		$tube = new PHPTube ();
		$flv_http_path = $tube->download($code) ;

		$result[0] = $code;
		$result[1] = $flv_http_path;

		return $result;
	}
    /**
     * Extracts the appropriate third party video code used to generate
     * the player and thumbnail images
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_code   the third party video code
     */
	function getthumbnail($option)
	{
		$thumbnail = "http://img.youtube.com/vi/".$option."/default.jpg";
		$thumbnail = trim(strip_tags($thumbnail));
		return $thumbnail;
	}
    /**
     * Extracts the title of the third party video
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_title   the third party video title
     */
	function processtitle($option)
	{
		if (!defined('HWDVIDSPATH')) { define('HWDVIDSPATH', dirname(__FILE__).'/../../'); }
		$c = hwd_vs_Config::get_instance();

		$code = hwd_vs_tp::getcode($option);
		$code = $code[0];

		$watchvideourl = "http://www.youtube.com/watch?v=".$code;
		$watchvideourl = hwd_vs_tools::get_final_url( $watchvideourl );

		if (function_exists('curl_init')) {
			// get title with CURL
			$curl_handle=curl_init();
			curl_setopt($curl_handle,CURLOPT_URL,$watchvideourl);
			curl_setopt($curl_handle,CURLOPT_CONNECTTIMEOUT,2);
			curl_setopt($curl_handle,CURLOPT_RETURNTRANSFER,1);
			$buffer = curl_exec($curl_handle);
			curl_close($curl_handle);

			// check third party encoding and compare to system encoding
			// fix if necessary
			if (function_exists('mb_detect_encoding')) {
				if (mb_detect_encoding($buffer . 'a' , 'UTF-8, ISO-8859-1') == "ISO-8859-1") {
					$buffer = utf8_encode($buffer);
				}
			}

			if (empty($buffer))	{
				$ext_v_title[0] = 0;
				$ext_v_title[1] = "Unknown";
			} else {
				// get title information
				$fcontents = stristr($buffer, '<title>');
				$rest = substr($fcontents, 7);
				$extra = stristr($fcontents, '</title>');
				$titlelen = strlen($rest) - strlen($extra);
				$gettitle = trim(substr($rest, 0, $titlelen));
				$gettitle = substr($gettitle, 10);

				if (!$gettitle) {
					$ext_v_title[0] = 0;
					$ext_v_title[1] = "Unknown";
				} else {
					$ext_v_title[0] = 1;
					$ext_v_title[1] = $gettitle;
				}
			}
		} else if (function_exists('get_meta_tags')) {
			if (@get_meta_tags($watchvideourl)) {
				$tags = get_meta_tags($watchvideourl);
				$ext_v_title[0] = 1;
				$ext_v_title[1] = $tags['title'];
			} else {
				$ext_v_title[0] = 0;
				$ext_v_title[1] = "Unknown";
			}
		} else {
			$ext_v_title[0] = 0;
			$ext_v_title[1] = "Unknown";
		}
		$ext_v_title[1] = hwd_vs_tools::truncateText($ext_v_title[1], 300);
		$ext_v_title[1] = addslashes(trim(strip_tags($ext_v_title[1])));

		if ($ext_v_title[1]=='') {$ext_v_title[1] = "Unknown";}
		return $ext_v_title;
	}
    /**
     * Extracts the description of the third party video
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_title   the third party video description
     */
	function processdescr($option)
	{
		if (!defined('HWDVIDSPATH')) { define('HWDVIDSPATH', dirname(__FILE__).'/../../'); }
		$c = hwd_vs_Config::get_instance();

		$code = hwd_vs_tp::getcode($option);
		$code = $code[0];

		$watchvideourl = "http://www.youtube.com/watch?v=".$code;
		$watchvideourl = hwd_vs_tools::get_final_url( $watchvideourl );

		if (function_exists('curl_init')) {
			// get title with CURL
			$curl_handle=curl_init();
			curl_setopt($curl_handle,CURLOPT_URL,$watchvideourl);
			curl_setopt($curl_handle,CURLOPT_CONNECTTIMEOUT,2);
			curl_setopt($curl_handle,CURLOPT_RETURNTRANSFER,1);
			$buffer = curl_exec($curl_handle);
			curl_close($curl_handle);

			// check third party encoding and compare to system encoding
			// fix if necessary
			if (function_exists('mb_detect_encoding')) {
				if (mb_detect_encoding($buffer . 'a' , 'UTF-8, ISO-8859-1') == "ISO-8859-1") {
					$buffer = utf8_encode($buffer);
				}
			}

			if (empty($buffer))	{
				$ext_v_descr[0] = 0;
				$ext_v_descr[1] = "Unknown";
			} else {
				$tagst = strpos($buffer, '<meta name="description" content="');
				$tagst = $tagst + 34;
				$tagen = strpos($buffer, '">', $tagst);
				$tagle = $tagen - $tagst;
				$tag   = substr($buffer, $tagst, $tagle);
				if ($tag) {
					$ext_v_descr[0] = 1;
					$ext_v_descr[1] = $tag;
				} else {
					$ext_v_descr[0] = 0;
					$ext_v_descr[1] = "Unknown";
				}
			}
		} else if (function_exists('get_meta_tags')) {
			if (@get_meta_tags($watchvideourl)) {
				$tags = get_meta_tags($watchvideourl);
				$ext_v_descr[0] = 1;
				$ext_v_descr[1] = $tags['description'];
			} else {
				$ext_v_descr[0] = 0;
				$ext_v_descr[1] = "Unknown";
			}
		} else {
			$ext_v_descr[0] = 0;
			$ext_v_descr[1] = "Unknown";
		}
		$ext_v_descr[1] = hwd_vs_tools::truncateText($ext_v_descr[1], 500);
		$ext_v_descr[1] = addslashes(trim(strip_tags($ext_v_descr[1])));

		if ($ext_v_descr[1]=='') {$ext_v_descr[1] = "Unknown";}
		return $ext_v_descr;
	}
    /**
     * Extracts the keywords of the third party video
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_title   the third party video keywords
     */
	function processkeywo($option)
	{
		if (!defined('HWDVIDSPATH')) { define('HWDVIDSPATH', dirname(__FILE__).'/../../'); }
		$c = hwd_vs_Config::get_instance();

		$code = hwd_vs_tp::getcode($option);
		$code = $code[0];

		$watchvideourl = "http://www.youtube.com/watch?v=".$code;
		$watchvideourl = hwd_vs_tools::get_final_url( $watchvideourl );

		if (function_exists('curl_init')) {
			// get title with CURL
			$curl_handle=curl_init();
			curl_setopt($curl_handle,CURLOPT_URL,$watchvideourl);
			curl_setopt($curl_handle,CURLOPT_CONNECTTIMEOUT,2);
			curl_setopt($curl_handle,CURLOPT_RETURNTRANSFER,1);
			$buffer = curl_exec($curl_handle);
			curl_close($curl_handle);

			// check third party encoding and compare to system encoding
			// fix if necessary
			if (function_exists('mb_detect_encoding')) {
				if (mb_detect_encoding($buffer . 'a' , 'UTF-8, ISO-8859-1') == "ISO-8859-1") {
					$buffer = utf8_encode($buffer);
				}
			}

			if (empty($buffer))	{
				$ext_v_keywo[0] = 0;
				$ext_v_keywo[1] = "Unknown";
			} else {
				$tagst = strpos($buffer, '<meta name="keywords" content="');
				$tagst = $tagst + 31;
				$tagen = strpos($buffer, '">', $tagst);
				$tagle = $tagen - $tagst;
				$tag   = substr($buffer, $tagst, $tagle);
				if ($tag) {
					$ext_v_keywo[0] = 1;
					$ext_v_keywo[1] = $tag;
				} else {
					$ext_v_keywo[0] = 0;
					$ext_v_keywo[1] = "Unknown";
				}
			}
		} else if (function_exists('get_meta_tags')) {
			if (@get_meta_tags($watchvideourl)) {
				$tags = get_meta_tags($watchvideourl);
				$ext_v_keywo[0] = 1;
				$ext_v_keywo[1] = $tags['keywords'];
			} else {
				$ext_v_keywo[0] = 0;
				$ext_v_keywo[1] = "Unknown";
			}
		} else {
			$ext_v_keywo[0] = 0;
			$ext_v_keywo[1] = "Unknown";
		}
		$ext_v_keywo[1] = hwd_vs_tools::truncateText($ext_v_keywo[1], 300);
		$ext_v_keywo[1] = addslashes(trim(strip_tags($ext_v_keywo[1])));

		if ($ext_v_keywo[1]=='') {$ext_v_keywo[1] = "Unknown";}
		return $ext_v_keywo;
	}
    /**
     * Extracts the duration of the third party video
     *
     * @param string $option  the 'embed code' input given by user
     * @return       $ext_v_title   the third party video duration
     */
	function processdurat($option)
	{
		if (!defined('HWDVIDSPATH')) { define('HWDVIDSPATH', dirname(__FILE__).'/../../'); }
		$c = hwd_vs_Config::get_instance();

		$ext_v_durat[0] = 0;
		$ext_v_durat[1] = "0:00:00";
		return $ext_v_durat;
	}
}

require_once 'Request.php';

/**
 * @package    hwdVideoShare
 * @author     Dave Horsfall <info@highwooddesign.co.uk>
 * @copyright  2008 Highwood Design
 * @license    http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @version    1.1.4 Alpha RC3.5
 */
 if (!class_exists('PHPTube')) {
	class PHPTube {

		var $cookies;
		var $mgr;
		var $req;
		var $debug = true;
		var $auth = false;

		// Function:	PHPTube   ... Initialize PHPTube-Object
		// Paramters:	$username ... YouTube Accountname (if empty, upload is disabled)
		//						$password ... YouTube Passwort (if empty, upload is disabled)
		//						$debug	  ... Debug-Flag

		function PHPTube () {


		}

		// Function:	download  ... Download any Video-Clip from YouTube
		// Paramters:	$video_id ... Video-ID as given in YouTube URL (f.e. the Video at http://youtube.com/watch?v=TWZ5j-SNVKs
		//							  has the ID "TWZ5j-SNVKs"
		//				$video_filename ... local path+filename, the video is downloaded to (check write-permissions!)

		function download ($video_id) {
			$url = "http://www.youtube.com/watch?v=".$video_id;
			$this->req =& new HTTP_Request($url);
			$response = $this->req->sendRequest();
			if (hwdPEAR::isError($response)) {
				echo $response->getMessage()."\n";
			} else {
				$page = $this->req->getResponseBody();
				//preg_match('/watch_fullscreen\?video_id=(.*?)&l=(.*?)+&t=(.*?)&/', $page, $match);
				preg_match('/"video_id": "(.*?)"/', $page, $match);
				$var_id = @$match[1];

				preg_match('/"t": "(.*?)"/', $page, $match);
				$var_t = @$match[1];

				$url = "";
				$url .= $var_id;
				$url .= "&t=";
				$url .= $var_t;
				$url = "http://www.youtube.com/get_video?video_id=".$url;
				if ($this->debug)
					return $url;


			}


		}


	}
}
?>